Class: Jav::BaseAction

Inherits:
Object
  • Object
show all
Includes:
Concerns::HasActionStimulusControllers, Concerns::HasFields
Defined in:
lib/jav/base_action.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Concerns::HasActionStimulusControllers

#get_stimulus_controllers

Methods included from Concerns::HasFields

#fields, #get_field, #get_field_definitions, #get_fields, #get_items, #get_tabs, #tab_groups, #tools

Constructor Details

#initialize(model: nil, resource: nil, user: nil, view: nil, arguments: {}) ⇒ BaseAction

Returns a new instance of BaseAction.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/jav/base_action.rb', line 54

def initialize(model: nil, resource: nil, user: nil, view: nil, arguments: {})
  @model = model
  @resource = resource
  @user = user
  @view = view
  @arguments = arguments

  self.class.message ||= I18n.t("jav.are_you_sure_you_want_to_run_this_option")
  self.class.confirm_button_label ||= I18n.t("jav.run")
  self.class.cancel_button_label ||= I18n.t("jav.cancel")

  @response ||= {}
  @response[:messages] = []
end

Instance Attribute Details

#argumentsObject (readonly)

Returns the value of attribute arguments.



17
18
19
# File 'lib/jav/base_action.rb', line 17

def arguments
  @arguments
end

#modelObject

Returns the value of attribute model.



16
17
18
# File 'lib/jav/base_action.rb', line 16

def model
  @model
end

#resourceObject

Returns the value of attribute resource.



16
17
18
# File 'lib/jav/base_action.rb', line 16

def resource
  @resource
end

#responseObject

Returns the value of attribute response.



16
17
18
# File 'lib/jav/base_action.rb', line 16

def response
  @response
end

#userObject

Returns the value of attribute user.



16
17
18
# File 'lib/jav/base_action.rb', line 16

def user
  @user
end

#viewObject

Returns the value of attribute view.



16
17
18
# File 'lib/jav/base_action.rb', line 16

def view
  @view
end

Class Method Details

.form_data_attributesObject



29
30
31
32
33
34
35
36
# File 'lib/jav/base_action.rb', line 29

def form_data_attributes
  # We can't respond with a file download from Turbo se we disable it on the form
  if may_download_file
    { turbo: turbo || false, remote: false }
  else
    { turbo: turbo, turbo_frame: :_top }.compact
  end
end

.submit_button_data_attributesObject

We can't respond with a file download from Turbo se we disable close the modal manually after a while (it's a hack, we know)



39
40
41
42
43
44
45
# File 'lib/jav/base_action.rb', line 39

def submit_button_data_attributes
  attributes = { action_target: "submit" }

  attributes[:action] = "click->modal#delayedClose" if may_download_file

  attributes
end

Instance Method Details

#action_nameObject



48
49
50
51
52
# File 'lib/jav/base_action.rb', line 48

def action_name
  return name if name.present?

  self.class.to_s.demodulize.underscore.humanize(keep_id_suffix: true)
end

#download(path, filename) ⇒ Object



196
197
198
199
200
201
202
# File 'lib/jav/base_action.rb', line 196

def download(path, filename)
  response[:type] = :download
  response[:path] = path
  response[:filename] = filename

  self
end

#error(text) ⇒ Object



151
152
153
154
155
# File 'lib/jav/base_action.rb', line 151

def error(text)
  add_message text, :error

  self
end

#fail(text) ⇒ Object



145
146
147
148
149
# File 'lib/jav/base_action.rb', line 145

def fail(text)
  Rails.logger.warn "DEPRECATION WARNING: Action fail method is deprecated in favor of error method and will be removed from Jav version 3.0.0"

  error text
end

#get_messageObject



69
70
71
72
73
74
75
# File 'lib/jav/base_action.rb', line 69

def get_message
  if self.class.message.respond_to? :call
    Jav::Hosts::ResourceRecordHost.new(block: self.class.message, record: @model, resource: @resource).handle
  else
    self.class.message
  end
end

#handle_action(**args) ⇒ Object



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/jav/base_action.rb', line 77

def handle_action(**args)
  models, fields, current_user, resource = args.values_at(:models, :fields, :current_user, :resource)
  # Fetching the field definitions and not the actual fields (get_fields) because they will break if the user uses a `visible` block and adds a condition using the `params` variable. The params are different in the show method and the handle method.
  action_fields = get_field_definitions.index_by(&:id)

  # For some fields, like belongs_to, the id and database_id differ (user vs user_id).
  # That's why we need to fetch the database_id for when we process the action.
  action_fields_by_database_id = action_fields.to_h do |_, value|
    [value.database_id.to_sym, value]
  end

  if fields.present?
    processed_fields = fields.to_unsafe_h.map do |name, value|
      field = action_fields_by_database_id[name.to_sym]

      next if field.blank?

      [name, field.resolve_attribute(value)]
    end

    processed_fields = processed_fields.compact_blank.to_h
  else
    processed_fields = {}
  end

  args = {
    fields: processed_fields.with_indifferent_access,
    current_user: current_user,
    resource: resource
  }

  args[:models] = models unless standalone

  handle(**args)

  self
end

#hydrate_fields(model: nil, view: nil) ⇒ Object

We're overriding this method to hydrate with the proper resource attribute.



205
206
207
208
209
210
211
# File 'lib/jav/base_action.rb', line 205

def hydrate_fields(model: nil, view: nil)
  fields.map do |field|
    field.hydrate(model: @model, view: @view, resource: resource)
  end

  self
end

#inform(text) ⇒ Object



157
158
159
160
161
# File 'lib/jav/base_action.rb', line 157

def inform(text)
  add_message text, :info

  self
end

#keep_modal_openObject



169
170
171
172
173
# File 'lib/jav/base_action.rb', line 169

def keep_modal_open
  response[:keep_modal_open] = true

  self
end

#param_idObject



135
136
137
# File 'lib/jav/base_action.rb', line 135

def param_id
  self.class.to_s
end

#redirect_to(path = nil, **args, &block) ⇒ Object



182
183
184
185
186
187
188
# File 'lib/jav/base_action.rb', line 182

def redirect_to(path = nil, **args, &block)
  response[:type] = :redirect
  response[:redirect_args] = args
  response[:path] = (block.presence || path)

  self
end

#reloadObject



190
191
192
193
194
# File 'lib/jav/base_action.rb', line 190

def reload
  response[:type] = :reload

  self
end

#silentObject

Add a placeholder silent message from when a user wants to do a redirect action or something similar



176
177
178
179
180
# File 'lib/jav/base_action.rb', line 176

def silent
  add_message nil, :silent

  self
end

#succeed(text) ⇒ Object



139
140
141
142
143
# File 'lib/jav/base_action.rb', line 139

def succeed(text)
  add_message text, :success

  self
end

#visible_in_view(parent_resource: nil) ⇒ Object



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/jav/base_action.rb', line 115

def visible_in_view(parent_resource: nil)
  if visible.blank?
    # Hide on the :new view by default
    return false if view == :new

    # Show on all other views
    return true
  end

  # Run the visible block if available
  Jav::Hosts::VisibilityHost.new(
    block: visible,
    params: params,
    parent_resource: parent_resource,
    resource: @resource,
    view: @view,
    arguments: arguments
  ).handle
end

#warn(text) ⇒ Object



163
164
165
166
167
# File 'lib/jav/base_action.rb', line 163

def warn(text)
  add_message text, :warning

  self
end